@@ -1,43 +1,32 @@
 OC.L10N.register(
     "logreader",
     {
-    "144" : "144",
-    "140" : "140",
-    "141" : "141",
-    "71" : "71",
-    "142" : "142",
-    "padLeft" : "padLeft",
-    "padRight" : "padRight",
-    "137" : "137",
-    "60" : "60",
-    "61" : "61",
-    "62" : "62",
-    "63" : "63",
-    "64" : "64",
-    "65" : "65",
-    "66" : "66",
-    "captured" : "capturado",
-    "bubbled" : "bubbled",
     "Error parsing log" : "Registro de análise de erros",
+    "Caused by " : "Causado por",
+    "Debug" : "Depurar ",
+    "Info" : "Informações ",
+    "Warning" : "Aviso",
+    "Error" : "Erro",
+    "Fatal" : "Fatal",
+    "Copy" : "Copiar",
+    "Copy raw" : "Copia básica",
+    "Copy formatted" : "Cópia formatada",
+    "No server logs" : "Sem registros no servidor",
+    "One or more entries are hidden by the log level filter" : "Uma ou mais entradas estão escondidas pelo filtro de nível de registro",
+    "Everything is working fine" : "Tudo está funcionando bem",
+    "Level" : "Nível",
+    "App" : "Aplicativo",
+    "Message" : "Mensagem",
+    "Time" : "Hora",
+    "Load log file …" : "Carregar arquivo de log ... ",
+    "Invalid log file" : "Arquivo de log inválido ",
     "Log levels" : "Níveis de registro",
     "Log content" : "Conteúdo do registro",
     "Live update" : "Atualização ao vivo",
     "Download logs" : "Registro de downloads",
-    "No server logs" : "Sem registros no servidor",
-    "One or more entries are hidden by the log level filter" : "Uma ou mais entradas estão escondidas pelo filtro de nível de registro",
-    "Everything is working fine" : "Tudo está funcionando bem",
     "Logging" : "Registro",
     "Log Reader" : "Leitor de Registro",
-    "add" : "adicionar",
-    "subtract" : "subtrair",
-    "37" : "37",
-    "38" : "38",
-    "39" : "39",
-    "40" : "40",
-    "41" : "41",
-    "42" : "42",
-    "43" : "43",
-    "_hidden" : "_hidden",
-    "toPrimitive" : "toPrimitive"
+    "A log reader for Nextcloud" : "Um leitor de logs para Nextcloud",
+    "Log reader for Nextcloud" : "Leitor de logs para Nextcloud"
 },
 "nplurals=2; plural=(n > 1);");
