@@ -9,7 +9,9 @@ OC.L10N.register(
     "Email sent" : "E-mail envoyé",
     "Private" : "Privé",
     "Local" : "Local",
+    "Federated" : "Fédéré",
     "Only synchronize to trusted servers" : "Ne synchroniser qu'avec les serveurs de confiance",
+    "Published" : "Publier",
     "Synchronize to trusted servers and the global and public address book" : "Synchronisation avec les serveurs de confiance et le carnet d'adresses mondial et public",
     "Verify" : "Vérifier",
     "Verifying …" : "Vérification en cours...",
@@ -63,7 +65,6 @@ OC.L10N.register(
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Veuillez fournir un mot de passe administrateur de récupération de données, sinon toutes les données utilisateur seront perdues.",
     "Wrong admin recovery password. Please check the password and try again." : "Mot de passe administrateur de récupération de données non valable. Veuillez vérifier le mot de passe et essayer à nouveau.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "L'infrastructure d'arrière-plan ne supporte pas la modification de mot de passe, mais la clef de chiffrement de l'utilisateur a été mise à jour.",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "le partage Federated Cloud ou l'installation et la mise à jour d'applications par l'app store",
     "Federated Cloud Sharing" : "Federated Cloud Sharing",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL utilise %1$s version (%2$s), qui est une version obsolète. Veuillez mettre à jour votre système d'exploitation, ou des fonctionnalités telles que %3$s ne fonctionneront pas correctement.",
     "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Impossible de déterminer si la version TLS de cURL est périmée ou non en raison d’une erreur survenue lors de la demande HTTPS contre https://nextcloud.com. Veuillez consulter le fichier journal de nextcloud pour plus de détails.",
@@ -74,6 +75,7 @@ OC.L10N.register(
     "Email could not be sent. Check your mail server log" : "L'email n'a pu être envoyé. Vérifiez le journal du serveur de messagerie",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Une erreur est survenue lors de l'envoi de l'e-mail. Veuillez vérifier vos paramètres. (Erreur: %s)",
     "You need to set your user email before being able to send test emails." : "Vous devez définir une adresse e-mail dans vos paramètres personnels avant de pouvoir envoyer des e-mails de test.",
+    "Invalid user" : "Utilisateur non valable",
     "Invalid mail address" : "Adresse e-mail non valide",
     "Settings saved" : "Paramètres sauvegardés",
     "Unable to change full name" : "Impossible de modifier le nom complet",
@@ -114,6 +116,9 @@ OC.L10N.register(
     "Sharing" : "Partage",
     "Personal info" : "Informations personnelles",
     "Mobile & desktop" : "Mobile & bureau",
+    "Email server" : "Serveur e-mail",
+    "Security & setup warnings" : "Avertissements de sécurité & configuration",
+    "Background jobs" : "Tâches de fond",
     "Create" : "Créer",
     "Change" : "Modifier",
     "Delete" : "Supprimer",
@@ -124,6 +129,7 @@ OC.L10N.register(
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Certains certificats SSL importés par les utilisateurs sont présents et ne sont plus utilisés avec Nextcloud 21. Ils peuvent être importés par l'interface en ligne de commande via la commande \"occ security:certificates:import\". Leurs chemins dans le dossier data sont affichés ci-dessous.",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "L'ancien format de chiffrement côté serveur est activé. Nous recommandons de le désactiver.",
     "Nextcloud settings" : "Paramètres Nextcloud",
+    "None" : "Aucun",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "L'authentification à deux facteurs peut être forcée pour tous les utilisateurs et des groupes spécifiques. S'ils n'ont pas un fournisseur à deux facteurs configuré, ils ne seront pas capable de s'identifier au système.",
     "Enforce two-factor authentication" : "Imposer l'authentification à deux facteurs",
     "Limit to groups" : "Limiter aux groupes",
@@ -175,10 +181,6 @@ OC.L10N.register(
     "Google Chrome for Android" : "Google Chrome pour Android",
     "iPhone" : "iPhone",
     "iPad" : "iPad",
-    "Nextcloud iOS app" : "Application iOS Nextcloud",
-    "Nextcloud Android app" : "Application Android Nextcloud",
-    "Nextcloud Talk for iOS" : "Nextcloud Talk pour iOS",
-    "Nextcloud Talk for Android" : "Nextcloud Talk pour Android",
     "Sync client - {os}" : "Client de synchronisation - {os}",
     "This session" : "Cette session",
     "Device" : "Appareil",
@@ -203,13 +205,17 @@ OC.L10N.register(
     "Copied!" : "Copié !",
     "Copy" : "Copier",
     "Could not copy app password. Please copy it manually." : "Impossible de copier le mot de passe de l'application. Merci de le copier manuellement.",
+    "Your email address" : "Votre adresse e-mail",
+    "No email address set" : "Aucune adresse e-mail configurée",
+    "Language" : "Langue",
+    "Help translate" : "Aidez à traduire",
+    "No language set" : "Aucune langue définie",
+    "Add" : "Ajouter",
     "You do not have permissions to see the details of this user" : "Vous n'avez pas les autorisations pour voir le détail de cet utilisateur",
     "Add new password" : "Ajouter un nouveau mot de passe",
     "Add new email address" : "Ajouter une nouvelle adresse e-mail",
-    "Add user in group" : "Ajouter un utilisateur au groupe",
     "Set user as admin for" : "Définir en tant qu'administrateur pour",
     "Select user quota" : "Sélectionner le quota de l'utilisateur ",
-    "No language set" : "Aucune langue définie",
     "Delete user" : "Supprimer l'utilisateur",
     "Wipe all devices" : "Effacer tous les appareils",
     "Disable user" : "Désactiver l'utilisateur",
@@ -226,28 +232,25 @@ OC.L10N.register(
     "Edit User" : "Modifier l'utilisateur",
     "Toggle user actions menu" : "Basculer le menu des actions de l'utilisateur",
     "{size} used" : "{size} utilisé",
+    "New user" : "Nouvel utilisateur",
     "Will be autogenerated" : "Sera généré automatiquement",
     "Display name" : "Nom à afficher",
     "Email" : "Adresse e-mail",
     "Default language" : "Langue par défaut",
     "Add a new user" : "Ajouter un nouvel utilisateur",
-    "Close" : "Fermer",
     "Group admin for" : "Administrateur de groupe pour",
     "Quota" : "Quota",
-    "Language" : "Langue",
     "User backend" : "Retour utilisateur",
     "Storage location" : "Emplacement du stockage",
     "Last login" : "Dernière connexion",
     "No users in here" : "Aucun utilisateur",
     "Default quota" : "Quota par défaut",
     "Common languages" : "Langues communes",
-    "All languages" : "Toutes les langues",
     "Password change is disabled because the master key is disabled" : "Le changement de mot de passe est désactivé car la clé principale est désactivée",
     "Passwordless authentication requires a secure connection." : "L'authentification sans mot de passe requiert une connexion sécurisée.",
     "Add WebAuthn device" : "Ajouter un appareil WebAuthn",
     "Please authorize your WebAuthn device." : "Veuillez autoriser votre appareil WebAuthn.",
     "Name your device" : "Nom de votre appareil",
-    "Add" : "Ajouter",
     "Adding your device …" : "Ajout de votre appareil…",
     "Server error while trying to add WebAuthn device" : "Erreur du serveur lors de l'ajout de l'appareil WebAuthn ",
     "Server error while trying to complete WebAuthn device registration" : "Erreur du serveur lors de l'enregistrement de l'appareil WebAuthn",
@@ -267,49 +270,47 @@ OC.L10N.register(
     "Details" : "Détails",
     "Changelog" : "Journal des modifications",
     "by {author}\n{license}" : "par {author}\n{license}",
-    "New user" : "Nouvel utilisateur",
     "Enter group name" : "Saisissez le nom du groupe",
     "Add group" : "Ajouter un groupe",
-    "Everyone" : "Tout le monde",
     "Admins" : "Administrateurs",
     "Disabled users" : "Utilisateurs désactivés",
     "Remove group" : "Supprimer le groupe",
     "Default quota:" : "Quota par défaut :",
     "Select default quota" : "Sélectionner le quota par défaut",
     "Show Languages" : "Afficher les langues",
-    "Show last login" : "Montrer la dernière connexion",
+    "Show last login" : "Afficher la dernière connexion",
     "Show user backend" : "Montrer la source de l'identifiant",
     "Show storage path" : "Afficher le chemin du stockage",
     "Send email to new user" : "Envoyer un e-mail aux utilisateurs créés",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Vous êtes sur le point de supprimer le groupe {group}. Les utilisateurs ne seront PAS supprimés.",
     "Please confirm the group removal " : "Veuillez confirmer la suppression du groupe",
+    "Address" : "Adresse",
+    "Full name" : "Nom complet",
+    "Phone number" : "Numéro de téléphone",
+    "Twitter" : "Twitter",
+    "Website" : "Site web",
     "Download and enable" : "Télécharger et activer",
     "Enable" : "Activer",
     "Enable untested app" : "Activer les app non-testées",
-    "The app will be downloaded from the app store" : "Cette application va être téléchargée depuis l'app store",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Cette application n'est pas indiquée comme étant compatible avec votre version de Nextcloud. Si vous continuez vous pourrez toujours installer l'app. Notez cependant qu'elle pourrait ne pas fonctionner comme prévu.",
     "Never" : "Jamais",
     "An error occured during the request. Unable to proceed." : "Une erreur est survenue durant la requête. Impossible de traiter la demande.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'application a été activée mais doit être mise à jour. Vous allez être redirigé vers la page des mises à jour dans 5 secondes.",
     "App update" : "Mise à jour de l'application",
-    "Error: This app can not be enabled because it makes the server unstable" : "Erreur : Cette application ne peut pas être activée car cela rend le serveur instable.",
     "Administrator documentation" : "Documentation administrateur",
     "Documentation" : "Documentation",
     "Forum" : "Forum",
-    "None" : "Aucun",
     "Login" : "Login",
     "Plain" : "En clair",
     "NT LAN Manager" : "Gestionnaire du réseau NT",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
-    "Email server" : "Serveur e-mail",
     "Open documentation" : "Voir la documentation",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Il est important d'indiquer un serveur afin de pouvoir envoyer des mails en cas de perte de mot de passe et pour d'autres notifications.",
     "Send mode" : "Mode d'envoi",
     "Encryption" : "Chiffrement",
     "Sendmail mode" : "mode Sendmail",
     "From address" : "Adresse source",
-    "mail" : "e-mail",
     "Authentication method" : "Méthode d'authentification",
     "Authentication required" : "Authentification requise",
     "Server address" : "Adresse du serveur",
@@ -320,7 +321,6 @@ OC.L10N.register(
     "Save" : "Enregistrer",
     "Test email settings" : "Tester les paramètres e-mail",
     "Send email" : "Envoyer un e-mail",
-    "Security & setup warnings" : "Avertissements de sécurité & configuration",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Il est important pour la sécurité et la performance de votre instance que celle-ci soit correctement configurée. Afin de vous aider, votre instance Nextcloud effectue des vérifications automatiques. Pour de plus amples informations, veuillez consulter la documentation liée.",
     "All checks passed." : "Tous les tests ont réussi.",
     "There are some errors regarding your setup." : "Il y a quelques erreurs concernant votre configuration.",
@@ -345,7 +345,6 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Vous devez migrer vos clés de chiffrement de l'ancienne version (ownCloud <= 8.0) vers la nouvelle. Veuillez activer l'application \"Default Encryption Module\" et exécuter 'occ encryption:migrate'",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Vous devez migrer vos clés de chiffrement de l'ancienne version (ownCloud <= 8.0) vers la nouvelle.",
     "Start migration" : "Démarrer la migration",
-    "Background jobs" : "Tâches de fond",
     "Last job execution ran %s. Something seems wrong." : "Quelque chose s'est mal passé lors de l'exécution de la dernière tâche %s.",
     "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Certaines tâches n'ont pas été exécutées depuis %s. Vous pourriez augmenter la fréquence d'exécution.",
     "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Certaines tâches n’ont pas été exécutées depuis 1%s. Veuillez envisager de passer à un système cron.",
@@ -361,8 +360,6 @@ OC.L10N.register(
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "En tant qu'administrateur, vous pouvez affiner le comportement de partage. Veuillez consulter la documentation pour plus d'informations.",
     "Allow apps to use the Share API" : "Autoriser les applications à utiliser l'API de partage",
     "Set default expiration date for shares" : "Définir une date d'expiration par défaut pour les partages",
-    "Expire after " : "Expiration après ",
-    "days" : "jours",
     "Enforce expiration date" : "Imposer la date d'expiration",
     "Allow public uploads" : "Autoriser les téléversements publics",
     "Always ask for a password" : "Toujours demander un mot de passe",
@@ -392,50 +389,39 @@ OC.L10N.register(
     "You are a member of the following groups:" : "Vous êtes un membre des groupes suivants :",
     "You are using <strong>%s</strong>" : "Vous utilisez <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Vous utilisez <strong>%1$s</strong> sur <strong>%2$s</strong> (<strong>%3$s%% </strong>)",
-    "Full name" : "Nom complet",
-    "No display name set" : "Aucun nom d'affichage configuré",
-    "Your email address" : "Votre adresse e-mail",
-    "No email address set" : "Aucune adresse e-mail configurée",
-    "For password reset and notifications" : "Pour la réinitialisation du mot de passe et les notifications",
-    "Phone number" : "Numéro de téléphone",
     "Your phone number" : "Votre numéro de téléphone",
-    "Address" : "Adresse",
     "Your postal address" : "Votre adresse postale",
-    "Website" : "Site web",
     "It can take up to 24 hours before the account is displayed as verified." : "Cela peut prendre jusqu'à 24 heures avant que le compte soit affiché comme vérifié.",
     "Link https://…" : "Lien https://…",
-    "Twitter" : "Twitter",
     "Twitter handle @…" : "Pseudo Twitter @...",
-    "Help translate" : "Aidez à traduire",
     "Locale" : "Paramètres régionaux",
     "Current password" : "Mot de passe actuel",
     "New password" : "Nouveau mot de passe",
     "Change password" : "Changer de mot de passe",
     "Use a second factor besides your password to increase security for your account." : "Utiliser un second facteur d'authentification en plus de votre mot de passe pour augmenter la sécurité de votre compte.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si vous utilisez des applications tierces pour vous connecter à Nextcloud, assurez-vous de créer et de configurer un mot de passe d'application pour chacune avant d'activer l'authentification à deux facteurs.",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Une erreur est survenue. Veuillez fournir un certificat PEM encodé au format ASCII.",
-    "Valid until {date}" : "Valide jusqu'au {date}",
-    "Only visible to local users" : "Visible uniquement par les utilisateurs locaux",
-    "Only visible to you" : "Visible uniquement par vous",
-    "Contacts" : "Contacts",
-    "Visible to local users and to trusted servers" : "Visible par les utilisateurs locaux et les serveurs de confiance",
-    "Public" : "Publique",
-    "Will be synced to a global and public address book" : "Va être synchronisé dans un carnet d'adresse global et public",
-    "by" : "par",
-    "SSL Root Certificates" : "Certificats Racines SSL",
-    "Common Name" : "Nom d'usage",
-    "Valid until" : "Valide jusqu'à",
-    "Issued By" : "Délivré par",
-    "Valid until %s" : "Valide jusqu'à %s",
-    "Import root certificate" : "Importer un certificat racine",
-    "Execute one task with each page loaded" : "Exécute une tâche à chaque chargement de page",
-    "Allow users to share via link" : "Autoriser les utilisateurs à partager par lien",
-    "Set default expiration date for link shares" : "Date d'expiration par défaut pour les partages par lien",
-    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Activer l'autocomplétion des noms d'utilisateurs dans la fenêtre de partage. Si cette option est désactivée, les noms complets ou les adresses e-mail doivent être indiqués.",
-    "Restrict username autocompletion to users within the same groups" : "Limiter la saisie automatique du nom d'utilisateur aux utilisateurs appartenant aux mêmes groupes",
-    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Afficher les conditions d'utilisation sur la page publique de téléversement (seulement lorsque la liste des fichiers est masquée).",
     "Don't synchronize to servers" : "Ne pas synchroniser avec les serveurs",
     "Trusted" : "Approuvé",
-    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "Activer l'autocomplétion des noms d'utilisateurs dans la fenêtre de partage (Si cette option est désactivée, les noms complets ou les adresses e-mail doivent être indiqués)"
+    "Public" : "Publique",
+    "installing and updating apps via the app store or Federated Cloud Sharing" : "le partage Federated Cloud ou l'installation et la mise à jour d'applications par l'app store",
+    "Nextcloud iOS app" : "Application iOS Nextcloud",
+    "Nextcloud Android app" : "Application Android Nextcloud",
+    "Nextcloud Talk for iOS" : "Nextcloud Talk pour iOS",
+    "Nextcloud Talk for Android" : "Nextcloud Talk pour Android",
+    "Add user in group" : "Ajouter un utilisateur au groupe",
+    "Close" : "Fermer",
+    "All languages" : "Toutes les langues",
+    "Everyone" : "Tout le monde",
+    "The app will be downloaded from the app store" : "Cette application va être téléchargée depuis l'app store",
+    "Error: This app can not be enabled because it makes the server unstable" : "Erreur : Cette application ne peut pas être activée car cela rend le serveur instable.",
+    "mail" : "e-mail",
+    "Expire after " : "Expiration après ",
+    "days" : "jours",
+    "Allow users to share via link" : "Autoriser les utilisateurs à partager par lien",
+    "Set default expiration date for link shares" : "Date d'expiration par défaut pour les partages par lien",
+    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "Activer l'autocomplétion des noms d'utilisateurs dans la fenêtre de partage (Si cette option est désactivée, les noms complets ou les adresses e-mail doivent être indiqués)",
+    "Restrict username autocompletion to users within the same groups" : "Limiter la saisie automatique du nom d'utilisateur aux utilisateurs appartenant aux mêmes groupes",
+    "No display name set" : "Aucun nom d'affichage configuré",
+    "For password reset and notifications" : "Pour la réinitialisation du mot de passe et les notifications"
 },
 "nplurals=2; plural=(n > 1);");
