@@ -2,14 +2,18 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Impossible d’écrire dans le répertoire « config » !",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire \"config\"",
+    "This can usually be fixed by giving the webserver write access to the config directory." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire de configuration.",
+    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option \"config_is_read_only\" sur true.",
     "See %s" : "Voir %s",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option \"config_is_read_only\" sur true.",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire \"config\". Voir %s",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option \"config_is_read_only\" sur true. Voir %s",
-    "The files of the app %$1s were not replaced correctly. Make sure it is a version compatible with the server." : "Les fichiers de l'application %$1s n'ont pas été remplacés correctement. Veuillez vérifier que c'est une version compatible avec le serveur.",
+    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Les fichiers de l'application %1$s n'ont pas été remplacés correctement. Veuillez vérifier que c'est une version compatible avec le serveur.",
     "Sample configuration detected" : "Configuration d'exemple détectée",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Il a été détecté que la configuration donnée à titre d'exemple a été copiée. Cela peut rendre votre installation inopérante et n'est pas pris en charge. Veuillez lire la documentation avant d'effectuer des modifications dans config.php",
+    "%s email verification" : "Vérification de l'e-mail %s",
+    "Email verification" : "Vérification de l'e-mail",
+    "Click the following button to confirm your email." : "Cliquez sur le bouton ci-dessous pour confirmer votre e-mail.",
+    "Click the following link to confirm your email." : "Cliquez sur le lien ci-dessous pour confirmer votre e-mail.",
+    "Confirm your email" : "Confirmer votre e-mail",
+    "Other activities" : "Autres activités",
     "%1$s and %2$s" : "%1$s et %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s et %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s et %4$s",
@@ -17,30 +21,48 @@ OC.L10N.register(
     "Education Edition" : "Édition pour l'éducation ",
     "Enterprise bundle" : "Pack pour entreprise",
     "Groupware bundle" : "Pack pour travail collaboratif",
+    "Hub bundle" : "Noyau de paquets",
     "Social sharing bundle" : "Pack pour partage social",
     "PHP %s or higher is required." : "PHP %s ou supérieur est requis.",
     "PHP with a version lower than %s is required." : "PHP avec une version antérieure à %s est requis.",
     "%sbit or higher PHP required." : "PHP %sbits ou supérieur est requis.",
-    "Following databases are supported: %s" : "Les bases de données suivantes sont supportées : %s",
+    "The following architectures are supported: %s" : "Les architectures suivantes sont prises en charge : %s",
+    "The following databases are supported: %s" : "Les bases de données suivantes sont prises en charge : %s",
     "The command line tool %s could not be found" : "La commande %s est introuvable",
     "The library %s is not available." : "La librairie %s n'est pas disponible.",
     "Library %1$s with a version higher than %2$s is required - available version %3$s." : "La librairie %1$s doit être au moins à la version %2$s. Version disponible : %3$s.",
     "Library %1$s with a version lower than %2$s is required - available version %3$s." : "La librairie %1$s doit avoir une version antérieure à %2$s. Version disponible : %3$s.",
-    "Following platforms are supported: %s" : "Les plateformes suivantes sont prises en charge : %s",
+    "The following platforms are supported: %s" : "Les plateformes suivantes sont prises en charge : %s",
     "Server version %s or higher is required." : "Un serveur de version %s ou supérieure est requis.",
     "Server version %s or lower is required." : "Un serveur de version %s ou inférieure est requis.",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "L'utilisateur connecté doit être un administrateur, un sous-administrateur ou se voir accorder des droits spéciaux pour accéder à ce réglage",
+    "Logged in user must be an admin or sub admin" : "L'utilisateur connecté doit être administrateur ou sous-administrateur",
     "Logged in user must be an admin" : "L'utilisateur connecté doit être un administrateur",
+    "Wiping of device %s has started" : "L'effaçage de l'appareil %s a démarré",
+    "Wiping of device »%s« has started" : "L'effaçage de l'appareil « %s » a démarré",
+    "»%s« started remote wipe" : "« %s » a démarré l'effaçage distant",
+    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "L'appareil ou l'application « %s » a démarré le processus d'effaçage distant. Vous recevrez un autre e-mail une fois le processus terminé",
+    "Wiping of device %s has finished" : "L'effaçage de l'appareil %s est terminé",
+    "Wiping of device »%s« has finished" : "L'effaçage de l'appareil « %s » est terminé",
+    "»%s« finished remote wipe" : "« %s » a terminé l'effaçage distant",
+    "Device or application »%s« has finished the remote wipe process." : "L'appareil ou l'application « %s » a terminé le processus d'effaçage distant.",
+    "Remote wipe started" : "Nettoyage à distance lancé",
+    "A remote wipe was started on device %s" : "Un nettoyage à distance a été lancé sur l'appareil %s",
+    "Remote wipe finished" : "Nettoyage à distance terminé",
+    "The remote wipe on %s has finished" : "Le nettoyage à distance de %s est terminé",
+    "Authentication" : "Authentification",
     "Unknown filetype" : "Type de fichier inconnu",
     "Invalid image" : "Image non valable",
     "Avatar image is not square" : "L'image d'avatar n'est pas carré",
+    "View profile" : "Voir le profil",
     "today" : "aujourd'hui",
     "tomorrow" : "demain",
     "yesterday" : "hier",
-    "_in %n day_::_in %n days_" : ["dans %n jour","dans %n jours"],
+    "_in %n day_::_in %n days_" : ["dans %n jour","dans %n jours"],
     "_%n day ago_::_%n days ago_" : ["il y a %n jour","il y a %n jours"],
     "next month" : "mois suivant",
     "last month" : "le mois dernier",
-    "_in %n month_::_in %n months_" : ["dans %n mois","dans %n mois"],
+    "_in %n month_::_in %n months_" : ["dans %n mois","dans %n mois"],
     "_%n month ago_::_%n months ago_" : ["Il y a %n mois","Il y a %n mois"],
     "next year" : "année suivante",
     "last year" : "l'année dernière",
@@ -52,7 +74,12 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["il y a %n minute","il y a %n minutes"],
     "in a few seconds" : "dans quelques secondes",
     "seconds ago" : "il y a quelques secondes",
+    "Empty file" : "Fichier vide",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Le module avec l'ID: %s n'existe pas. Merci de l'activer dans les paramètres d'applications ou de contacter votre administrateur.",
+    "File already exists" : "Le fichier existe déjà",
+    "Invalid path" : "Chemin incorrect",
+    "Failed to create file from template" : "Impossible de créer le fichier à partir du modèle",
+    "Templates" : "Modèles",
     "File name is a reserved word" : "Ce nom de fichier est un mot réservé",
     "File name contains at least one invalid character" : "Le nom de fichier contient un (des) caractère(s) non valide(s)",
     "File name is too long" : "Nom de fichier trop long",
@@ -67,76 +94,57 @@ OC.L10N.register(
     "Settings" : "Paramètres",
     "Log out" : "Se déconnecter",
     "Users" : "Utilisateurs",
+    "Email" : "E-mail",
+    "Mail %s" : "Courrier %s",
+    "Phone" : "Téléphone",
+    "Call %s" : "Appel %s",
+    "Twitter" : "Twitter",
+    "View %s on Twitter" : "Voir %s sur Twitter",
+    "Website" : "Site web",
+    "Visit %s" : "Visiter %s",
+    "Address" : "Adresse",
+    "Profile picture" : "Photo de profil",
+    "About" : "À propos",
+    "Full name" : "Nom complet",
+    "Headline" : "Titre",
+    "Organisation" : "Organisme",
+    "Role" : "Rôle",
     "Unknown user" : "Utilisateur inconnu",
-    "Create" : "Créer",
-    "Change" : "Modifier",
-    "Delete" : "Supprimer",
-    "Share" : "Partager",
-    "Overview" : "Vue d'ensemble",
-    "Basic settings" : "Paramètres de base",
-    "Sharing" : "Partage",
-    "Security" : "Sécurité",
-    "Groupware" : "Travail collaboratif",
     "Additional settings" : "Paramètres supplémentaires",
-    "Personal info" : "Informations personnelles",
-    "Mobile & desktop" : "Mobile & bureau",
-    "Unlimited" : "Illimité",
-    "Verifying" : "Vérification en cours",
-    "Verifying …" : "Vérification en cours...",
-    "Verify" : "Vérifié",
     "%s enter the database username and name." : "%s entrez le nom d'utilisateur et le nom de la base de données.",
     "%s enter the database username." : "%s entrez le nom d'utilisateur de la base de données.",
     "%s enter the database name." : "%s entrez le nom de la base de données.",
     "%s you may not use dots in the database name" : "%s vous ne pouvez pas utiliser de points dans le nom de la base de données",
+    "MySQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base MySQL non valide(s)",
+    "You need to enter details of an existing account." : "Vous devez indiquer les détails d'un compte existant.",
     "Oracle connection could not be established" : "La connexion Oracle ne peut être établie",
     "Oracle username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base Oracle non valide(s)",
     "PostgreSQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base PostgreSQL non valide(s)",
-    "You need to enter details of an existing account." : "Vous devez indiquer les détails d'un compte existant.",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X n'est pas pris en charge et %s ne fonctionnera pas correctement sur cette plate-forme. Son utilisation est à vos risques et périls !",
     "For the best results, please consider using a GNU/Linux server instead." : "Pour obtenir les meilleurs résultats, vous devriez utiliser un serveur GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Il semble que cette instance %s fonctionne sur un environnement PHP 32-bit et open_basedir a été configuré dans php.ini. Cela engendre des problèmes avec les fichiers de taille supérieure à 4 Go et est donc fortement déconseillé.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Veuillez supprimer la configuration open_basedir de votre php.ini ou utiliser une version PHP 64-bit.",
     "Set an admin username." : "Spécifiez un nom d'utilisateur pour l'administrateur.",
     "Set an admin password." : "Spécifiez un mot de passe pour l'administrateur.",
-    "Can't create or write into the data directory %s" : "Impossible de créer, ou d'écrire dans, le répertoire des données %s",
-    "Invalid Federated Cloud ID" : "ID Federated Cloud incorrect",
-    "Sharing %s failed, because the backend does not allow shares from type %i" : "Le partage de %s a échoué car l’infrastructure n'autorise pas les partages de type %i",
-    "Sharing %s failed, because the file does not exist" : "Le partage de %s a échoué car le fichier n'existe pas",
-    "You are not allowed to share %s" : "Vous n'êtes pas autorisé à partager %s",
-    "Sharing %s failed, because you can not share with yourself" : "Le partage de %s a échoué car vous ne pouvez pas partager avec vous-même",
-    "Sharing %1$s failed, because the user %2$s does not exist" : "Le partage de %1$s a échoué car l'utilisateur %2$s n'existe pas",
-    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "Le partage de %1$s a échoué car l'utilisateur %2$s n'est membre d'aucun groupe auquel %3$s appartient",
-    "Sharing %1$s failed, because this item is already shared with %2$s" : "Le partage de %1$s a échoué car cet élément est déjà partagé avec %2$s",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Le partage de %1$s a échoué car cet élément est déjà partagé avec l'utilisateur %2$s",
-    "Sharing %1$s failed, because the group %2$s does not exist" : "Le partage de %1$s a échoué car le groupe %2$s n'existe pas",
-    "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Le partage de %1$s a échoué car %2$s n'est pas membre du groupe %3$s",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Vous devez fournir un mot de passe pour créer un lien public, seuls les liens protégés sont autorisées.",
-    "Sharing %s failed, because sharing with links is not allowed" : "Le partage de %s a échoué car le partage par lien n'est pas permis",
-    "Not allowed to create a federated share with the same user" : "Non autorisé à créer un partage fédéré avec le même utilisateur",
-    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Le partage de %1$s a échoué : impossible de trouver %2$s. Le serveur est peut-être momentanément injoignable.",
-    "Share type %1$s is not valid for %2$s" : "Le type de partage %1$s n'est pas valide pour %2$s",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Impossible de configurer la date d'expiration. Un partage ne peut expirer plus de %s après sa création",
-    "Cannot set expiration date. Expiration date is in the past" : "Impossible de configurer la date d'expiration : elle est dans le passé.",
+    "Cannot create or write into the data directory %s" : "Impossible de créer ou d'écrire dans le répertoire des données %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Le service de partage %s doit implémenter l'interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "Service de partage %s non trouvé",
     "Sharing backend for %s not found" : "Le service de partage pour %s est introuvable",
-    "Sharing failed, because the user %s is the original sharer" : "Le partage a échoué car l'utilisateur %s est le propriétaire original",
-    "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "Le partage de %1$s a échoué car les permissions dépassent celles accordées à %2$s",
-    "Sharing %s failed, because resharing is not allowed" : "Le partage de %s a échoué car le repartage n'est pas autorisé",
-    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "Le partage de %1$s a échoué car le service %2$s n'a pas trouvé sa source..",
-    "Sharing %s failed, because the file could not be found in the file cache" : "Le partage de %s a échoué car le fichier n'a pas été trouvé dans les fichiers mis en cache.",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$sa partagé \"%2$s\" avec vous et veut ajouter :",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$sa partagé \"%2$s\" avec vous et veut ajouter",
-    "»%s« added a note to a file shared with you" : "\"%s\" a ajouté une note à un fichier partagé avec vous",
-    "Open »%s«" : "Ouvrir «%s»",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s a partagé « %2$s » avec vous et souhaite ajouter :",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s a partagé « %2$s » avec vous et souhaite ajouter",
+    "»%s« added a note to a file shared with you" : "%s a ajouté une note à un fichier partagé avec vous",
+    "Open »%s«" : "Ouvrir « %s »",
     "%1$s via %2$s" : "%1$s via %2$s",
-    "Can’t increase permissions of %s" : "Impossible d'augmenter les permissions de %s",
-    "Files can’t be shared with delete permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de suppression",
-    "Files can’t be shared with create permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de création",
+    "You are not allowed to share %s" : "Vous n'êtes pas autorisé à partager %s",
+    "Cannot increase permissions of %s" : "Impossible d'augmenter les permissions de %s",
+    "Files cannot be shared with delete permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de suppression",
+    "Files cannot be shared with create permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de création",
     "Expiration date is in the past" : "La date d'expiration est dans le passé",
-    "Can’t set expiration date more than %s days in the future" : "Impossible de définir la date d'expiration à plus de %s jours dans le futur",
-    "%1$s shared »%2$s« with you" : "%1$s a partagé «%2$s» avec vous",
-    "%1$s shared »%2$s« with you." : "%1$s a partagé «%2$s» avec vous.",
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Impossible de définir la date d'expiration à dans plus de %s jour","Impossible de définir la date d'expiration à dans plus de %s jours"],
+    "Sharing is only allowed with group members" : "Le partage n'est que possible qu'avec les membres du groupe",
+    "Sharing %s failed, because this item is already shared with user %s" : "Impossible de partager %s car il est déjà partagé avec l'utilisateur %s",
+    "%1$s shared »%2$s« with you" : "%1$s a partagé « %2$s » avec vous",
+    "%1$s shared »%2$s« with you." : "%1$s a partagé « %2$s » avec vous.",
     "Click the button below to open it." : "Cliquez sur le bouton ci-dessous pour l'ouvrir",
     "The requested share does not exist anymore" : "Le partage demandé n'existe plus",
     "Could not find category \"%s\"" : "Impossible de trouver la catégorie \"%s\"",
@@ -185,33 +193,37 @@ OC.L10N.register(
     "Oct." : "Oct.",
     "Nov." : "Nov.",
     "Dec." : "Déc.",
+    "The user limit has been reached and the user was not created." : "Le nombre maximum d'utilisateurs a été atteint, l'utilisateur n'a pas pu être créé.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Seuls les caractères suivants sont autorisés dans un nom d'utilisateur : \"a-z\", \"A-Z\", \"0-9\", \"_@-\" et \".\" (le point)",
     "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
     "Username contains whitespace at the beginning or at the end" : "Le nom d'utilisateur contient des espaces au début ou à la fin",
     "Username must not consist of dots only" : "Le nom d'utilisateur ne doit pas être composé uniquement de points",
+    "Username is invalid because files already exist for this user" : "Ce nom d'utilisateur n'est pas valide car des fichiers existent déjà pour cet utilisateur",
     "A valid password must be provided" : "Un mot de passe valide doit être saisi",
     "The username is already being used" : "Ce nom d'utilisateur est déjà utilisé",
     "Could not create user" : "Impossible de créer l'utilisateur",
     "User disabled" : "Utilisateur désactivé",
     "Login canceled by app" : "L'authentification a été annulé par l'application",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "L'application \"%1$s\" ne peut pas être installée à cause des dépendances suivantes non satisfaites : %2$s",
-    "a safe home for all your data" : "un endroit sûr pour toutes vos données",
+    "a safe home for all your data" : "un lieu sûr pour toutes vos données",
     "File is currently busy, please try again later" : "Le fichier est actuellement utilisé, veuillez réessayer plus tard",
-    "Can't read file" : "Impossible de lire le fichier",
+    "Cannot read file" : "Impossible de lire le fichier",
     "Application is not enabled" : "L'application n'est pas activée",
     "Authentication error" : "Erreur d'authentification",
     "Token expired. Please reload page." : "La session a expiré. Veuillez recharger la page.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Aucun pilote de base de données n’est installé (sqlite, mysql ou postgresql).",
     "Cannot write into \"config\" directory" : "Impossible d’écrire dans le répertoire \"config\"",
+    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire \"config\". Voir %s",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option \"config_is_read_only\" sur true. Voir %s",
     "Cannot write into \"apps\" directory" : "Impossible d’écrire dans le répertoire \"apps\"",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire \"apps\" ou en désactivant l'appstore dans le fichier de configuration. Voir %s",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire des applications ou en désactivant le magasin d'applications dans le fichier de configuration.",
     "Cannot create \"data\" directory" : "Impossible de créer le dossier \"data\"",
     "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s",
     "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Le problème de permissions peut généralement être résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s.",
     "Setting locale to %s failed" : "Echec de la spécification des paramètres régionaux à %s",
     "Please install one of these locales on your system and restart your webserver." : "Veuillez installer l'un de ces paramètres régionaux sur votre système et redémarrer votre serveur web.",
-    "Please ask your server administrator to install the module." : "Veuillez demander à votre administrateur d’installer le module.",
     "PHP module %s not installed." : "Le module PHP %s n’est pas installé.",
+    "Please ask your server administrator to install the module." : "Veuillez demander à votre administrateur d’installer le module.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Le paramètre PHP \"%s\" n'est pas \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajuster ce paramètre dans php.ini fera fonctionner Nextcould à nouveau",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload est à \"%s\" alors que la valeur \"0\" est attendue",
@@ -224,8 +236,8 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Veuillez demander à votre administrateur serveur de redémarrer le serveur web.",
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requis",
     "Please upgrade your database version" : "Veuillez mettre à jour votre gestionnaire de base de données",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Veuillez changer les permissions du répertoire en mode 0770 afin que son contenu ne puisse pas être listé par les autres utilisateurs.",
     "Your data directory is readable by other users" : "Votre répertoire est lisible par les autres utilisateurs",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Veuillez changer les permissions du répertoire en mode 0770 afin que son contenu ne puisse pas être listé par les autres utilisateurs.",
     "Your data directory must be an absolute path" : "Le chemin de votre répertoire doit être un lien absolu",
     "Check the value of \"datadirectory\" in your configuration" : "Verifiez la valeur de \"datadirectory\" dans votre configuration",
     "Your data directory is invalid" : "Votre répertoire n'est pas valide",
@@ -241,41 +253,15 @@ OC.L10N.register(
     "Storage connection error. %s" : "Erreur de connexion à l'espace stockage. %s",
     "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
     "Storage connection timeout. %s" : "Le délai d'attente pour la connexion à l'espace de stockage a été dépassé. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "La librairie %s doit être au moins à la version %s. Version disponible : %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "La librairie %s doit avoir une version antérieure à %s. Version disponible : %s.",
-    "Personal" : "Personnel",
-    "Admin" : "Administration",
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Encryption" : "Chiffrement",
-    "Tips & tricks" : "Trucs et astuces",
-    "DB Error: \"%s\"" : "Erreur de la base de données : \"%s\"",
-    "Offending command was: \"%s\"" : "La requête en cause est : \"%s\"",
-    "Offending command was: \"%s\", name: %s, password: %s" : "La requête en cause est : \"%s\", nom : %s, mot de passe : %s",
-    "Sharing %s failed, because the user %s does not exist" : "Le partage de %s a échoué car l'utilisateur %s n'existe pas",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Le partage de %s a échoué car l'utilisateur %s n'est membre d'aucun groupe auquel %s appartient",
-    "Sharing %s failed, because this item is already shared with %s" : "Le partage de %s a échoué car cet objet est déjà partagé avec %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "Le partage de %s a échoué car cet élément est déjà partagé avec l'utilisateur %s",
-    "Sharing %s failed, because the group %s does not exist" : "Le partage de %s a échoué car le groupe %s n'existe pas",
-    "Sharing %s failed, because %s is not a member of the group %s" : "Le partage de %s a échoué car %s n'est pas membre du groupe %s",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Le partage de %s a échoué : impossible de trouver %s. Peut-être le serveur est-il momentanément injoignable.",
-    "Share type %s is not valid for %s" : "Le type de partage %s n'est pas valide pour %s",
-    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Le réglage des permissions pour %s a échoué car les permissions dépassent celles accordées à %s",
-    "Setting permissions for %s failed, because the item was not found" : "Le réglage des permissions pour %s a échoué car l'objet n'a pas été trouvé",
-    "Cannot clear expiration date. Shares are required to have an expiration date." : "Impossible de supprimer la date d'expiration. Les partages doivent avoir une date d'expiration.",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Le partage de %s a échoué car les permissions dépassent celles accordées à %s",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Le partage de %s a échoué car le service %s n'a pas trouvé sa source..",
-    "Cannot increase permissions of %s" : "Impossible d'augmenter les permissions de %s",
-    "Files can't be shared with delete permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de suppression",
-    "Files can't be shared with create permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de création",
-    "Cannot set expiration date more than %s days in the future" : "Impossible de définir la date d'expiration à plus de %s jours dans le futur",
-    "%s shared »%s« with you" : "%s a partagé «%s» avec vous",
-    "%s shared »%s« with you." : "%s a partagé «%s» avec vous.",
-    "%s via %s" : "%s via %s",
-    "No app name specified" : "Aucun nom d'application spécifié",
-    "App '%s' could not be installed!" : "L'application \"%s\" ne peut pas être installée !",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'application \"%s\" ne peut pas être installée à cause des dépendances suivantes non satisfaites : %s",
-    "Sync clients" : "Clients de synchronisation",
-    "ID \"%s\" already used by cloud federation provider \"%s\"" : "L'identifiant \"%s\" est déjà utilisé par le fournisseur de cloud \"%s\""
+    "This can usually be fixed by giving the webserver write access to the config directory" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire \"config\"",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option \"config_is_read_only\" sur true.",
+    "Can't create or write into the data directory %s" : "Impossible de créer, ou d'écrire dans, le répertoire des données %s",
+    "Invalid Federated Cloud ID" : "ID Federated Cloud incorrect",
+    "Can’t increase permissions of %s" : "Impossible d'augmenter les permissions de %s",
+    "Files can’t be shared with delete permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de suppression",
+    "Files can’t be shared with create permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de création",
+    "Can’t set expiration date more than %s days in the future" : "Impossible de définir la date d'expiration à plus de %s jours dans le futur",
+    "Can't read file" : "Impossible de lire le fichier",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire des applications ou en désactivant l'appstore dans le fichier de configuration."
 },
 "nplurals=2; plural=(n > 1);");
